mocks

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 16, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockBenchmarker

type MockBenchmarker struct {
	mock.Mock
}

MockBenchmarker is an autogenerated mock type for the Benchmarker type

func NewMockBenchmarker

func NewMockBenchmarker(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockBenchmarker

NewMockBenchmarker creates a new instance of MockBenchmarker. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockBenchmarker) Benchmark

func (_mock *MockBenchmarker) Benchmark(fs afero.Fs, n int) ([]tasks.Result, error)

Benchmark provides a mock function for the type MockBenchmarker

func (*MockBenchmarker) EXPECT

func (*MockBenchmarker) String

func (_mock *MockBenchmarker) String() string

String provides a mock function for the type MockBenchmarker

type MockBenchmarker_Benchmark_Call

type MockBenchmarker_Benchmark_Call struct {
	*mock.Call
}

MockBenchmarker_Benchmark_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Benchmark'

func (*MockBenchmarker_Benchmark_Call) Return

func (*MockBenchmarker_Benchmark_Call) Run

func (*MockBenchmarker_Benchmark_Call) RunAndReturn

type MockBenchmarker_Expecter

type MockBenchmarker_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockBenchmarker_Expecter) Benchmark

func (_e *MockBenchmarker_Expecter) Benchmark(fs interface{}, n interface{}) *MockBenchmarker_Benchmark_Call

Benchmark is a helper method to define mock.On call

  • fs afero.Fs
  • n int

func (*MockBenchmarker_Expecter) String

String is a helper method to define mock.On call

type MockBenchmarker_String_Call

type MockBenchmarker_String_Call struct {
	*mock.Call
}

MockBenchmarker_String_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'String'

func (*MockBenchmarker_String_Call) Return

func (*MockBenchmarker_String_Call) Run

func (*MockBenchmarker_String_Call) RunAndReturn

func (_c *MockBenchmarker_String_Call) RunAndReturn(run func() string) *MockBenchmarker_String_Call

Jump to