Documentation
¶
Overview ¶
Package tasks provides types and functions to execute tasks for implementation.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type TaskStatus ¶
type TaskStatus int
const ( StatusInvalid TaskStatus = iota // Invalid StatusPassed // Passed StatusUnverified // Unverified StatusFailed // Failed StatusError // Error )
type TaskType ¶
type TaskType int
TaskType represents the type of task to be executed.
func StringToTaskType ¶
Click to show internal directories.
Click to hide internal directories.